@@ -68,9 +68,13 @@
         <translation type="obsolete">cuteTube-QML - 0.7.7 in deutsch</translation>
     </message>
     <message>
-        <location filename="../AboutDialog.qml" line="44"/>
         <source>cuteTube-QML - 0.8.0</source>
-        <translation type="unfinished">cuteTube-QML - 0.8.0 in deutsch</translation>
+        <translation type="obsolete">cuteTube-QML - 0.8.0 in deutsch</translation>
+    </message>
+    <message>
+        <location filename="../AboutDialog.qml" line="44"/>
+        <source>cuteTube-QML - 0.8.2</source>
+        <translation type="unfinished">cuteTube-QML - 0.8.2 in deutsch</translation>
     </message>
     <message>
         <location filename="../AboutDialog.qml" line="56"/>
@@ -1292,14 +1296,80 @@
 <context>
     <name>UserInfoDialog</name>
     <message>
-        <location filename="../UserInfoDialog.qml" line="127"/>
+        <location filename="../UserInfoDialog.qml" line="106"/>
+        <source>Profile</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../UserInfoDialog.qml" line="152"/>
+        <source>Uploads</source>
+        <translation type="unfinished">Uploads</translation>
+    </message>
+    <message>
+        <location filename="../UserInfoDialog.qml" line="158"/>
         <source>Subscribers</source>
         <translation>Abonnenten</translation>
     </message>
     <message>
-        <location filename="../UserInfoDialog.qml" line="141"/>
+        <location filename="../UserInfoDialog.qml" line="178"/>
+        <source>Name</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../UserInfoDialog.qml" line="184"/>
+        <source>Age</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../UserInfoDialog.qml" line="197"/>
+        <location filename="../UserInfoDialog.qml" line="215"/>
+        <location filename="../UserInfoDialog.qml" line="221"/>
+        <source>None</source>
+        <translation type="unfinished">Kein proxy</translation>
+    </message>
+    <message>
+        <location filename="../UserInfoDialog.qml" line="203"/>
+        <source>Gender</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../UserInfoDialog.qml" line="209"/>
+        <source>Location</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../UserInfoDialog.qml" line="215"/>
+        <source>Male</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../UserInfoDialog.qml" line="215"/>
+        <source>Female</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../UserInfoDialog.qml" line="236"/>
+        <source>About</source>
+        <translation type="unfinished">Über</translation>
+    </message>
+    <message>
+        <location filename="../UserInfoDialog.qml" line="253"/>
+        <source>No info</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../UserInfoDialog.qml" line="268"/>
+        <source>Unsubscribe</source>
+        <translation type="unfinished">Abonnement kündigen</translation>
+    </message>
+    <message>
+        <location filename="../UserInfoDialog.qml" line="268"/>
+        <source>Subscribe</source>
+        <translation type="unfinished">Abonnieren</translation>
+    </message>
+    <message>
         <source>Videos</source>
-        <translation>Videos</translation>
+        <translation type="obsolete">Videos</translation>
     </message>
 </context>
 <context>
