@@ -48,9 +48,13 @@
         <translation type="obsolete">cuteTube-QML - 0.7.7 - Suomennos: d-iivil</translation>
     </message>
     <message>
-        <location filename="../AboutDialog.qml" line="44"/>
         <source>cuteTube-QML - 0.8.0</source>
-        <translation type="unfinished">cuteTube-QML - 0.8.0 - Suomennos: d-iivil</translation>
+        <translation type="obsolete">cuteTube-QML - 0.8.0 - Suomennos: d-iivil</translation>
+    </message>
+    <message>
+        <location filename="../AboutDialog.qml" line="44"/>
+        <source>cuteTube-QML - 0.8.2</source>
+        <translation type="unfinished">cuteTube-QML - 0.8.2 - Suomennos: d-iivil</translation>
     </message>
     <message>
         <location filename="../AboutDialog.qml" line="56"/>
@@ -1224,14 +1228,80 @@
 <context>
     <name>UserInfoDialog</name>
     <message>
-        <location filename="../UserInfoDialog.qml" line="127"/>
+        <location filename="../UserInfoDialog.qml" line="106"/>
+        <source>Profile</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../UserInfoDialog.qml" line="152"/>
+        <source>Uploads</source>
+        <translation type="unfinished">Lataukset</translation>
+    </message>
+    <message>
+        <location filename="../UserInfoDialog.qml" line="158"/>
         <source>Subscribers</source>
         <translation>Tilaajat</translation>
     </message>
     <message>
-        <location filename="../UserInfoDialog.qml" line="141"/>
+        <location filename="../UserInfoDialog.qml" line="178"/>
+        <source>Name</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../UserInfoDialog.qml" line="184"/>
+        <source>Age</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../UserInfoDialog.qml" line="197"/>
+        <location filename="../UserInfoDialog.qml" line="215"/>
+        <location filename="../UserInfoDialog.qml" line="221"/>
+        <source>None</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../UserInfoDialog.qml" line="203"/>
+        <source>Gender</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../UserInfoDialog.qml" line="209"/>
+        <source>Location</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../UserInfoDialog.qml" line="215"/>
+        <source>Male</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../UserInfoDialog.qml" line="215"/>
+        <source>Female</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../UserInfoDialog.qml" line="236"/>
+        <source>About</source>
+        <translation type="unfinished">Tietoja</translation>
+    </message>
+    <message>
+        <location filename="../UserInfoDialog.qml" line="253"/>
+        <source>No info</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../UserInfoDialog.qml" line="268"/>
+        <source>Unsubscribe</source>
+        <translation type="unfinished">Peru tilaus</translation>
+    </message>
+    <message>
+        <location filename="../UserInfoDialog.qml" line="268"/>
+        <source>Subscribe</source>
+        <translation type="unfinished">Tilaa</translation>
+    </message>
+    <message>
         <source>Videos</source>
-        <translation>Videot</translation>
+        <translation type="obsolete">Videot</translation>
     </message>
 </context>
 <context>
