@@ -5,7 +5,7 @@
     <name>AboutDialog</name>
     <message>
         <location filename="../AboutDialog.qml" line="44"/>
-        <source>cuteTube-QML - 0.8.0</source>
+        <source>cuteTube-QML - 0.8.2</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
@@ -1038,14 +1038,80 @@
 <context>
     <name>UserInfoDialog</name>
     <message>
-        <location filename="../UserInfoDialog.qml" line="127"/>
+        <location filename="../UserInfoDialog.qml" line="106"/>
+        <source>Profile</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../UserInfoDialog.qml" line="152"/>
+        <source>Uploads</source>
+        <translation type="unfinished">Uploads</translation>
+    </message>
+    <message>
+        <location filename="../UserInfoDialog.qml" line="158"/>
         <source>Subscribers</source>
         <translation>Subscritores</translation>
     </message>
     <message>
-        <location filename="../UserInfoDialog.qml" line="141"/>
+        <location filename="../UserInfoDialog.qml" line="178"/>
+        <source>Name</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../UserInfoDialog.qml" line="184"/>
+        <source>Age</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../UserInfoDialog.qml" line="197"/>
+        <location filename="../UserInfoDialog.qml" line="215"/>
+        <location filename="../UserInfoDialog.qml" line="221"/>
+        <source>None</source>
+        <translation type="unfinished">Nenhum</translation>
+    </message>
+    <message>
+        <location filename="../UserInfoDialog.qml" line="203"/>
+        <source>Gender</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../UserInfoDialog.qml" line="209"/>
+        <source>Location</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../UserInfoDialog.qml" line="215"/>
+        <source>Male</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../UserInfoDialog.qml" line="215"/>
+        <source>Female</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../UserInfoDialog.qml" line="236"/>
+        <source>About</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../UserInfoDialog.qml" line="253"/>
+        <source>No info</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../UserInfoDialog.qml" line="268"/>
+        <source>Unsubscribe</source>
+        <translation type="unfinished">Anular Subscrição</translation>
+    </message>
+    <message>
+        <location filename="../UserInfoDialog.qml" line="268"/>
+        <source>Subscribe</source>
+        <translation type="unfinished">Subscrever</translation>
+    </message>
+    <message>
         <source>Videos</source>
-        <translation>Vídeos</translation>
+        <translation type="obsolete">Vídeos</translation>
     </message>
 </context>
 <context>
