@@ -153,6 +153,8 @@ function loadAccountView() {
         loader.item.favourites.connect(loadVideos);
         loader.item.playlists.connect(loadPlaylists);
         loader.item.subscriptions.connect(loadSubscriptions);
+        loader.item.goToVideo.connect(loadVideoInfo);
+        loader.item.goToUserVideos.connect(loadUserVideos);
         notificationArea.addTitle(qsTr("My Channel"));
         windowView.incrementCurrentIndex();
     }
