@@ -350,7 +350,7 @@ void YouTube::replyToComment(const QString &videoId, const QString &commentId, c
 }
 
 void YouTube::getVideoUrl(const QString &videoId) {
-    QString playerUrl = "http://www.youtube.com/get_video_info?&video_id=" + videoId.toAscii() + "&ps=default&eurl=&gl=US&hl=en";
+    QString playerUrl = "http://www.youtube.com/get_video_info?&video_id=" + videoId.toAscii() + "&el=detailpage&ps=default&eurl=&gl=US&hl=en";
     QNetworkAccessManager *manager = new QNetworkAccessManager(this);
     QNetworkRequest request;
     request.setUrl(QUrl(playerUrl));
